@@ -123,6 +123,12 @@ class TimeUnit:
     def value(self) -> int:
         return self._value
 
+    def toRawUnit(self, unit: TimeUnit.UnitType) -> float:
+        if unit.conversionFactor <= self._unitType.conversionFactor:
+            return float(unit(self))
+        divider = unit.conversionFactor / self._unitType.conversionFactor
+        return self._value / divider
+
     def _arithmetic(self, operation: _ArithmeticOperation, other: SupportedValue) -> TimeUnit:
         operationDetails = TimeUnit._ARITHMETIC[operation]
 
